@@ -38,6 +38,7 @@ type GlobalFlags struct {
 	watchConfig string
 	pidFile     string
 	plugindDir  string
+	password    string
 	test        bool
 	debug       bool
 	once        bool
@@ -81,6 +82,11 @@ func (t *Telegraf) Init(pprofErr <-chan error, f Filters, g GlobalFlags, w Windo
 	t.secretstoreFilters = f.secretstore
 	t.GlobalFlags = g
 	t.WindowFlags = w
+
+	// Set global password
+	if g.password != "" {
+		config.Password = config.NewSecret([]byte(g.password))
+	}
 }
 
 func (t *Telegraf) ListSecretStores() ([]string, error) {
@@ -210,13 +216,8 @@ func (t *Telegraf) loadConfiguration() (*config.Config, error) {
 	c.SecretStoreFilters = t.secretstoreFilters
 
 	var configFiles []string
-	// providing no "config" flag should load default config
-	if len(t.config) == 0 {
-		configFiles = append(configFiles, "")
-	} else {
-		configFiles = append(configFiles, t.config...)
-	}
 
+	configFiles = append(configFiles, t.config...)
 	for _, fConfigDirectory := range t.configDir {
 		files, err := config.WalkDirectory(fConfigDirectory)
 		if err != nil {
@@ -225,6 +226,12 @@ func (t *Telegraf) loadConfiguration() (*config.Config, error) {
 		configFiles = append(configFiles, files...)
 	}
 
+	// providing no "config" or "config-directory" flag(s) should load default
+	// configuration files
+	if len(configFiles) == 0 {
+		configFiles = append(configFiles, "")
+	}
+
 	t.configFiles = configFiles
 	if err := c.LoadAll(configFiles...); err != nil {
 		return c, err
