@@ -4,6 +4,7 @@ package exec
 import (
 	"bytes"
 	_ "embed"
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -19,28 +20,33 @@ import (
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal"
+	"github.com/influxdata/telegraf/models"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/plugins/parsers"
 	"github.com/influxdata/telegraf/plugins/parsers/nagios"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
 const MaxStderrBytes int = 512
 
+type exitcodeHandlerFunc func([]telegraf.Metric, error, []byte) []telegraf.Metric
+
 type Exec struct {
 	Commands    []string        `toml:"commands"`
 	Command     string          `toml:"command"`
 	Environment []string        `toml:"environment"`
 	Timeout     config.Duration `toml:"timeout"`
+	Log         telegraf.Logger `toml:"-"`
 
 	parser parsers.Parser
 
 	runner Runner
-	Log    telegraf.Logger `toml:"-"`
+
+	// Allow post processing of command exit codes
+	exitcodeHandler   exitcodeHandlerFunc
+	parseDespiteError bool
 }
 
 func NewExec() *Exec {
@@ -63,7 +69,7 @@ func (c CommandRunner) Run(
 ) ([]byte, []byte, error) {
 	splitCmd, err := shellquote.Split(command)
 	if err != nil || len(splitCmd) == 0 {
-		return nil, nil, fmt.Errorf("exec: unable to parse command, %s", err)
+		return nil, nil, fmt.Errorf("exec: unable to parse command: %w", err)
 	}
 
 	cmd := osExec.Command(splitCmd[0], splitCmd[1:]...)
@@ -105,8 +111,7 @@ func (c CommandRunner) truncate(buf bytes.Buffer) bytes.Buffer {
 		buf.Truncate(i)
 	}
 	if didTruncate {
-		//nolint:errcheck,revive // Will always return nil or panic
-		buf.WriteString("...")
+		buf.WriteString("...") //nolint:revive // will always return nil or panic
 	}
 	return buf
 }
@@ -122,7 +127,7 @@ func removeWindowsCarriageReturns(b bytes.Buffer) bytes.Buffer {
 			if len(byt) > 0 {
 				_, _ = buf.Write(byt)
 			}
-			if err == io.EOF {
+			if errors.Is(err, io.EOF) {
 				return buf
 			}
 		}
@@ -136,11 +141,10 @@ func (*Exec) SampleConfig() string {
 
 func (e *Exec) ProcessCommand(command string, acc telegraf.Accumulator, wg *sync.WaitGroup) {
 	defer wg.Done()
-	_, isNagios := e.parser.(*nagios.Parser)
 
 	out, errBuf, runErr := e.runner.Run(command, e.Environment, time.Duration(e.Timeout))
-	if !isNagios && runErr != nil {
-		err := fmt.Errorf("exec: %s for command '%s': %s", runErr, command, string(errBuf))
+	if !e.parseDespiteError && runErr != nil {
+		err := fmt.Errorf("exec: %w for command %q: %s", runErr, command, string(errBuf))
 		acc.AddError(err)
 		return
 	}
@@ -151,8 +155,8 @@ func (e *Exec) ProcessCommand(command string, acc telegraf.Accumulator, wg *sync
 		return
 	}
 
-	if isNagios {
-		metrics = nagios.AddState(runErr, errBuf, metrics)
+	if e.exitcodeHandler != nil {
+		metrics = e.exitcodeHandler(metrics, runErr, errBuf)
 	}
 
 	for _, m := range metrics {
@@ -162,6 +166,13 @@ func (e *Exec) ProcessCommand(command string, acc telegraf.Accumulator, wg *sync
 
 func (e *Exec) SetParser(parser parsers.Parser) {
 	e.parser = parser
+	unwrapped, ok := parser.(*models.RunningParser)
+	if ok {
+		if _, ok := unwrapped.Parser.(*nagios.Parser); ok {
+			e.exitcodeHandler = nagiosHandler
+			e.parseDespiteError = true
+		}
+	}
 }
 
 func (e *Exec) Gather(acc telegraf.Accumulator) error {
@@ -215,6 +226,10 @@ func (e *Exec) Init() error {
 	return nil
 }
 
+func nagiosHandler(metrics []telegraf.Metric, err error, msg []byte) []telegraf.Metric {
+	return nagios.AddState(err, msg, metrics)
+}
+
 func init() {
 	inputs.Add("exec", func() telegraf.Input {
 		return NewExec()
