@@ -15,6 +15,7 @@ import (
 	"net"
 	"os"
 	"strings"
+	"sync"
 	"time"
 
 	"github.com/influxdata/telegraf"
@@ -23,17 +24,17 @@ import (
 	"github.com/influxdata/telegraf/plugins/outputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
 const (
-	defaultEndpoint        = "127.0.0.1:12201"
-	defaultConnection      = "wan"
-	defaultMaxChunkSizeWan = 1420
-	defaultMaxChunkSizeLan = 8154
-	defaultScheme          = "udp"
-	defaultTimeout         = 5 * time.Second
+	defaultEndpoint         = "127.0.0.1:12201"
+	defaultConnection       = "wan"
+	defaultMaxChunkSizeWan  = 1420
+	defaultMaxChunkSizeLan  = 8154
+	defaultScheme           = "udp"
+	defaultTimeout          = 5 * time.Second
+	defaultReconnectionTime = 15 * time.Second
 )
 
 var defaultSpecFields = []string{"version", "host", "short_message", "full_message", "timestamp", "level", "facility", "line", "file"}
@@ -317,10 +318,18 @@ type Graylog struct {
 	ShortMessageField string          `toml:"short_message_field"`
 	NameFieldNoPrefix bool            `toml:"name_field_noprefix"`
 	Timeout           config.Duration `toml:"timeout"`
+	Reconnection      bool            `toml:"connection_retry"`
+	ReconnectionTime  config.Duration `toml:"connection_retry_wait_time"`
+	Log               telegraf.Logger `toml:"-"`
 	tlsint.ClientConfig
 
-	writer  io.Writer
-	closers []io.WriteCloser
+	writer      io.Writer
+	closers     []io.WriteCloser
+	unconnected []string
+	stopRetry   bool
+	wg          sync.WaitGroup
+
+	sync.Mutex
 }
 
 func (*Graylog) SampleConfig() string {
@@ -328,9 +337,6 @@ func (*Graylog) SampleConfig() string {
 }
 
 func (g *Graylog) Connect() error {
-	var writers []io.Writer
-	dialer := &net.Dialer{Timeout: time.Duration(g.Timeout)}
-
 	if len(g.Servers) == 0 {
 		g.Servers = append(g.Servers, "localhost:12201")
 	}
@@ -340,21 +346,92 @@ func (g *Graylog) Connect() error {
 		return err
 	}
 
-	for _, server := range g.Servers {
-		w := newGelfWriter(gelfConfig{Endpoint: server}, dialer, tlsCfg)
-		err := w.Connect()
-		if err != nil {
-			return fmt.Errorf("failed to connect to server [%s]: %v", server, err)
-		}
-		writers = append(writers, w)
-		g.closers = append(g.closers, w)
+	if g.Reconnection {
+		go g.connectRetry(tlsCfg)
+		return nil
 	}
 
+	unconnected, gelfs := g.connectEndpoints(g.Servers, tlsCfg)
+	if len(unconnected) > 0 {
+		servers := strings.Join(unconnected, ",")
+		return fmt.Errorf("connect: connection failed for %s", servers)
+	}
+	writers := make([]io.Writer, 0, len(gelfs))
+	closers := make([]io.WriteCloser, 0, len(gelfs))
+	for _, w := range gelfs {
+		writers = append(writers, w)
+		closers = append(closers, w)
+	}
+	g.Lock()
+	defer g.Unlock()
 	g.writer = io.MultiWriter(writers...)
+	g.closers = closers
+
 	return nil
 }
 
+func (g *Graylog) connectRetry(tlsCfg *tls.Config) {
+	var writers []io.Writer
+	var closers []io.WriteCloser
+	var attempt int64
+
+	g.wg.Add(1)
+
+	unconnected := append([]string{}, g.Servers...)
+	for {
+		unconnected, gelfs := g.connectEndpoints(unconnected, tlsCfg)
+		for _, w := range gelfs {
+			writers = append(writers, w)
+			closers = append(closers, w)
+		}
+		g.Lock()
+		g.unconnected = unconnected
+		stopRetry := g.stopRetry
+		g.Unlock()
+		if stopRetry {
+			g.Log.Info("Stopping connection retries...")
+			break
+		}
+		if len(unconnected) == 0 {
+			break
+		}
+		attempt++
+		servers := strings.Join(unconnected, ",")
+		g.Log.Infof("Not connected to endpoints %s after attempt #%d...", servers, attempt)
+		time.Sleep(time.Duration(g.ReconnectionTime))
+	}
+	g.Log.Info("Connected!")
+
+	g.Lock()
+	g.writer = io.MultiWriter(writers...)
+	g.closers = closers
+	g.Unlock()
+
+	g.wg.Done()
+}
+
+func (g *Graylog) connectEndpoints(servers []string, tlsCfg *tls.Config) ([]string, []gelf) {
+	writers := make([]gelf, 0, len(servers))
+	unconnected := make([]string, 0, len(servers))
+	dialer := &net.Dialer{Timeout: time.Duration(g.Timeout)}
+	for _, server := range servers {
+		w := newGelfWriter(gelfConfig{Endpoint: server}, dialer, tlsCfg)
+		if err := w.Connect(); err != nil {
+			g.Log.Warnf("failed to connect to server [%s]: %v", server, err)
+			unconnected = append(unconnected, server)
+			continue
+		}
+		writers = append(writers, w)
+	}
+	return unconnected, writers
+}
+
 func (g *Graylog) Close() error {
+	g.Lock()
+	g.stopRetry = true
+	g.Unlock()
+	g.wg.Wait()
+
 	for _, closer := range g.closers {
 		_ = closer.Close()
 	}
@@ -362,6 +439,17 @@ func (g *Graylog) Close() error {
 }
 
 func (g *Graylog) Write(metrics []telegraf.Metric) error {
+	g.Lock()
+	writer := g.writer
+	g.Unlock()
+
+	if writer == nil {
+		g.Lock()
+		unconnected := strings.Join(g.unconnected, ",")
+		g.Unlock()
+
+		return fmt.Errorf("not connected to %s", unconnected)
+	}
 	for _, metric := range metrics {
 		values, err := g.serialize(metric)
 		if err != nil {
@@ -369,9 +457,9 @@ func (g *Graylog) Write(metrics []telegraf.Metric) error {
 		}
 
 		for _, value := range values {
-			_, err := g.writer.Write([]byte(value))
+			_, err = writer.Write([]byte(value))
 			if err != nil {
-				return fmt.Errorf("error writing message: %q, %v", value, err)
+				return fmt.Errorf("error writing message: %q: %w", value, err)
 			}
 		}
 	}
@@ -445,7 +533,8 @@ func fieldInSpec(field string) bool {
 func init() {
 	outputs.Add("graylog", func() telegraf.Output {
 		return &Graylog{
-			Timeout: config.Duration(defaultTimeout),
+			Timeout:          config.Duration(defaultTimeout),
+			ReconnectionTime: config.Duration(defaultReconnectionTime),
 		}
 	})
 }
